ListViewBaseCell class

Inheritance
Mixed-in types
Available extensions

Constructors

ListViewBaseCell({Key? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
item ListViewBaseItem
cellVM
getter/setter pairinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ListViewBaseCell>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didSelect(ListViewBaseItem item) → dynamic
点击选中了cell
inherited
didSelectMoreItem<S extends ListViewSectionItemType<ListViewItemType>, P extends Object>(ListViewBaseItem item, S sectionItem, P? pageItem) → dynamic
更多参数输入
inherited
didSelectPageVM<P extends Object>(ListViewBaseItem t, P pageItem) → dynamic
传入pageItem
inherited
didSelectSection<S extends ListViewSectionItemType<ListViewItemType>>(ListViewBaseItem t, S sectionItem) → dynamic
传入secttionItem
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
wrapGesture(dynamic tap()) Widget

Available on Widget, provided by the WrapGestureExtention extension

Operators

operator ==(Object other) bool
The equality operator.
inherited