ListViewAdapter<PVM extends Object> class
Constructors
- ListViewAdapter({Key? key, PVM? pageVM, double sectionSeparated = 0.0, Widget sectionSeparatedBuilder(int section)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemCount → int
-
计算cell的全部数量
no setter
-
列表底部,最多一个 listFooter
getter/setter pair
- listHeader ↔ Widget?
-
列表头部 最多一个 listFooter
getter/setter pair
- reloadCall ↔ dynamic Function()?
-
用于页面刷新
当数据_sectionItems发生改变的时候则会执行该函数
如果使用getXContruoller则使用pageVM 直接 update即可
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sectionSeparated → double
-
每个组之间的Separated
final
- sectionSeparatedBuilder → Widget Function(int section)?
-
如果设置sectionSeparatedBuilder则sectionSeparated将废弃
final
-
weakPageViewModel
↔ WeakReference<
PVM> ? -
页面的控制器VM
getter/setter pair
Methods
-
buildListCell(
BuildContext context, int index) → Widget - 构建cell heder footer separated对应的Widget
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reload(
{List< ListViewSectionItemType< ? sections}) → dynamicListViewItemType> > - 刷新分组列表 可能包含sectionHeader、sectionFooter、separated 用于比较复杂的分组列表
-
reloadSingleCell(
List< ListViewItemType> datas) → dynamic - 单列表的刷新 没有header、footer 每个cell可以存在自己的separated
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited